ChangeSet 1.1083.2.6, 2003/08/28 13:09:28-07:00, greg@kroah.com

[PATCH] PCI: add PCI_DEVICE_CLASS() macro to match PCI_DEVICE() macro.


 include/linux/pci.h |   14 ++++++++++++++
 1 files changed, 14 insertions(+)


diff -Nru a/include/linux/pci.h b/include/linux/pci.h
--- a/include/linux/pci.h	Thu Aug 28 15:02:27 2003
+++ b/include/linux/pci.h	Thu Aug 28 15:02:27 2003
@@ -533,6 +533,20 @@
 	.vendor = (vend), .device = (dev), \
 	.subvendor = PCI_ANY_ID, .subdevice = PCI_ANY_ID
 
+/**
+ * PCI_DEVICE_CLASS - macro used to describe a specific pci device class
+ * @dev_class: the class, subclass, prog-if triple for this device
+ * @dev_class_mask: the class mask for this device
+ *
+ * This macro is used to create a struct pci_device_id that matches a
+ * specific PCI class.  The vendor, device, subvendor, and subdevice 
+ * fields will be set to PCI_ANY_ID.
+ */
+#define PCI_DEVICE_CLASS(dev_class,dev_class_mask) \
+	.class = (dev_class), .class_mask = (dev_class_mask), \
+	.vendor = PCI_ANY_ID, .device = PCI_ANY_ID, \
+	.subvendor = PCI_ANY_ID, .subdevice = PCI_ANY_ID
+
 /* these external functions are only available when PCI support is enabled */
 #ifdef CONFIG_PCI
 
